@@ -47,7 +47,8 @@ class OcrParameter(QWidget, Ui_OcrParameter):
     ProcessBar_signal = pyqtSignal(float)
     WidgetColorSignal = pyqtSignal(str)
     def __init__(self, communication=None, token = ""):
-        super(OcrParameter, self).__init__(communication)
+        # super(OcrParameter, self).__init__(communication)
+        super().__init__(communication)
         self.setupUi(self)
 
         self.user = ""
